@@ -18,6 +18,13 @@ except:
 from mercurial.httprepo import httprepository
 from mercurial import mail
 
+# mercurial.demandimport incompatibility workaround,
+# would cause gnomekeyring, one of the possible
+# keyring backends, not to work.
+from mercurial.demandimport import ignore
+if "gobject._gobject" not in ignore:
+    ignore.append("gobject._gobject")
+
 import keyring
 from urlparse import urlparse
 import urllib2
